<?php
require_once("./lib.php");
@require_once("./config.inc.php");

// Check if the config succesfully loaded, or if the mandatory config fields are missing.
if ( empty($config) || empty($config['key']) || empty($config['input']) ) {
    echo "Please copy the config.sample.inc.php to config.inc.php and change the configuration to match your needs.";
    exit(1);
}

ini_set('memory_limit','1G');

function limitStringSize($str, $amount = 20) {
    if (strlen($str) > $amount)
        $str = substr($str, 0, $amount) . '...';
    return $str;
}

$kpc = new kpcrypt($config['key']);

echo "Key: " . $kpc->getKey() . " \n";

$enc_start = round(microtime(true) * 1000);

// Echo out the results
$encryptedData = $kpc->encryptData($config['input'], 'AES-256-CBC', TRUE);

$enc_end = round(microtime(true) * 1000) - $enc_start;

$dec_start = round(microtime(true) * 1000);
echo "Encrypted: " . limitStringSize($encryptedData);
echo "\n";
echo "Decrypted: " . limitStringSize($kpc->decryptData($encryptedData));

$dec_end = round(microtime(true) * 1000) - $dec_start;

echo "\n";
echo "Peak Memory: " . memory_get_peak_usage() / 1024 / 1024 . "Mb"; // Check the memory in kb
echo "\n\n";

// Calculate the string size increse
$inputSize  = strlen($config['input']); // Bytes
$outputSize = strlen($encryptedData); // Bytes

// Echo out sizing information
echo "Sizeof input: "           . strlen($config['input']) . "\n"; // Bytes
echo "Sizeof output:"           . strlen($encryptedData) . "\n"; // Bytes
echo "\n";
echo "Encryption Time: $enc_end ms\n"; // 9700k = ~210ms
echo "\n";
echo "Decryption Time: $dec_end ms\n";

echo "\n";